@@ -1,5 +1,5 @@
 package JMAP::Tester::Abort;
-$JMAP::Tester::Abort::VERSION = '0.008';
+$JMAP::Tester::Abort::VERSION = '0.009';
 use Moo;
 extends 'Throwable::Error';
 
@@ -23,9 +23,16 @@ has message => (
   required => 1,
 );
 
+has diagnostics => (
+  is => 'ro',
+);
+
 sub as_test_abort_events {
   return [
-    [ Ok => (pass => 0, name => $_[0]->message) ]
+    [ Ok => (pass => 0, name => $_[0]->message) ],
+    ($_[0]->diagnostics
+      ? (map {; [ Diag => (message => $_) ] } @{ $_[0]->diagnostics })
+      : ()),
   ];
 }
 
@@ -43,7 +50,7 @@ JMAP::Tester::Abort
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 AUTHOR
 
