@@ -1,9 +1,11 @@
 use v5.10.0;
 package JMAP::Tester::Response::Paragraph;
 # ABSTRACT: a group of sentences in a JMAP response
-$JMAP::Tester::Response::Paragraph::VERSION = '0.008';
+$JMAP::Tester::Response::Paragraph::VERSION = '0.009';
 use Moo;
 
+use JMAP::Tester::Abort 'abort';
+
 #pod =head1 OVERVIEW
 #pod
 #pod These objects represent paragraphs in the JMAP response.  That is, if your
@@ -20,6 +22,20 @@ use Moo;
 #pod
 #pod =cut
 
+sub client_id {
+  my ($self) = @_;
+  $self->_sentences->[0]->client_id;
+}
+
+sub BUILD {
+  abort("tried to build 0-sentence paragraph")
+    unless @{ $_[0]->_sentences };
+
+  my $client_id = $_[0]->_sentences->[0]->client_id;
+  abort("tried to build paragraph with non-uniform client_ids")
+    if grep {; $_->client_id ne $client_id } @{ $_[0]->_sentences };
+}
+
 has sentences => (is => 'bare', reader => '_sentences', required => 1);
 
 has _json_typist => (
@@ -125,7 +141,7 @@ JMAP::Tester::Response::Paragraph - a group of sentences in a JMAP response
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 OVERVIEW
 
