@@ -1,9 +1,12 @@
 use v5.10.0;
 package JMAP::Tester::Response::Sentence::Set;
 # ABSTRACT: the kind of sentence you get in reply to a setFoos call
-$JMAP::Tester::Response::Sentence::Set::VERSION = '0.008';
+$JMAP::Tester::Response::Sentence::Set::VERSION = '0.009';
 use Moo;
 
+use Data::Dumper ();
+use JMAP::Tester::Abort 'abort';
+
 #pod =head1 OVERVIEW
 #pod
 #pod A "Set" sentence is a kind of L<Sentence|JMAP::Tester::Response::Sentence>
@@ -16,6 +19,13 @@ has name      => (is => 'ro', required => 1);
 has arguments => (is => 'ro', required => 1);
 has client_id => (is => 'ro', required => 1);
 
+has _json_typist => (
+  is => 'ro',
+  handles => {
+    _strip_json_types => 'strip_types',
+  },
+);
+
 #pod =method new_state
 #pod
 #pod This returns the C<newState> in the result.
@@ -130,9 +140,41 @@ sub not_created_ids   { keys %{ $_[0]{arguments}{notCreated} }   }
 sub not_updated_ids   { keys %{ $_[0]{arguments}{notUpdated} }   }
 sub not_destroyed_ids { keys %{ $_[0]{arguments}{notDestroyed} } }
 
-sub create_errors     { $_[0]{arguments}{notCreated}   }
-sub update_errors     { $_[0]{arguments}{notUpdated}   }
-sub destroy_errors    { $_[0]{arguments}{notDestroyed} }
+sub create_errors     { $_[0]{arguments}{notCreated}   // {} }
+sub update_errors     { $_[0]{arguments}{notUpdated}   // {} }
+sub destroy_errors    { $_[0]{arguments}{notDestroyed} // {} }
+
+sub assert_no_errors {
+  my ($self) = @_;
+
+  my @errors;
+  local $Data::Dumper::Terse = 1;
+
+  if (keys %{ $self->create_errors }) {
+    push @errors, "notCreated: " .  Data::Dumper::Dumper(
+      $self->_strip_json_types( $self->create_errors )
+    );
+  }
+
+  if (keys %{ $self->update_errors }) {
+    push @errors, "notUpdated: " .  Data::Dumper::Dumper(
+      $self->_strip_json_types( $self->update_errors )
+    );
+  }
+
+  if (keys %{ $self->destroy_errors }) {
+    push @errors, "notDestroyed: " .  Data::Dumper::Dumper(
+      $self->_strip_json_types( $self->destroy_errors )
+    );
+  }
+
+  return unless @errors;
+
+  abort({
+    message     => "errors found in " . $self->name . " sentence",
+    diagnostics => \@errors,
+  });
+}
 
 1;
 
@@ -148,7 +190,7 @@ JMAP::Tester::Response::Sentence::Set - the kind of sentence you get in reply to
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 OVERVIEW
 
